@@ -66,7 +66,7 @@ class RTplot():
         return 0
     
     @enqueue
-    def scatter(self,x,y,labels=[],title='',style='points', jitter = True):
+    def scatter(self,x,y,labels=[],title='',style='points', jitter=True, multiplot=0):
         """
         Makes scatter plots from numpy arrays.
         if x and are multidimensional(lists of lists), multiple scatter plots will be generated, pairing rows.
@@ -75,6 +75,16 @@ class RTplot():
             -`x`: list of numbers or list of lists
             -`y`: list of numbers or list of lists
         """
+        assert len(x)==len(y)
+        if multiplot:
+            sq = numpy.sqrt(len(x))
+            ad = 1 if sq%1 >0.5 else 0
+            r= numpy.floor(sq);c=numpy.ceil(sq)+ad
+            if len(x) == 3:
+                r=3;c=1
+            self.gp('set multiplot layout %s,%s title "%s"'%(r, c, title))
+        else:
+            self.gp('set title "%s"'%title)
         if jitter:
             jt = numpy.random.normal(1, 1e-4,1)[0]
         else:
@@ -101,13 +111,21 @@ class RTplot():
             for n in range(x.shape[0]):
                 self.plots.append(Gnuplot.PlotItems.Data(x[n]*jt,y[n]*jt,title=labels[i],with_=style))
                 i += 1
-            self.gp.plot(*tuple(self.plots))
+            if multiplot:
+                [self.gp.plot(pl) for pl in self.plots]
+                self.gp('unset multiplot')
+            else:
+                self.gp.plot(*tuple(self.plots))
         elif len(x.shape) >2:
                 pass
         else:
             #print data
             self.plots.append(Gnuplot.PlotItems.Data(x*jt,y*jt,title=labels[0],with_=style))
-            self.gp.plot(*tuple(self.plots))
+            if multiplot:
+                [self.gp.plot(pl) for pl in self.plots]
+                self.gp('unset multiplot')
+            else:
+                self.gp.plot(*tuple(self.plots))
         if not self.hold:
             self.plots = []
         return 0
@@ -127,7 +145,8 @@ class RTplot():
         #self.gp('set style %s 1'%style)
         if multiplot:
             sq = numpy.sqrt(len(data))
-            r= numpy.floor(sq);c=numpy.ceil(sq)
+            ad = 1 if sq%1 >0.5 else 0
+            r= numpy.floor(sq);c=numpy.ceil(sq)+ad
             if len(data) == 3:
                 r=3;c=1
             self.gp('set multiplot layout %s,%s title "%s"'%(r, c, title))
@@ -181,7 +200,8 @@ class RTplot():
         '''
         if multiplot:
             sq = numpy.sqrt(len(data))
-            r= numpy.floor(sq);c=numpy.ceil(sq)
+            ad = 1 if sq%1 >0.5 else 0
+            r= numpy.floor(sq);c=numpy.ceil(sq)+ad
             if len(data) == 3:
                 r=3;c=1
             self.gp('set multiplot layout %s,%s title "%s"'%(r, c, title))
@@ -193,7 +213,7 @@ class RTplot():
         data = numpy.array(data)
         if not labels:
             labels = ['Var_%s'%i for i in range(data.shape[0])]
-        if len(data.shape) > 1 and len(data.shape) <= 2:
+        if len(data.shape) == 2:
             for n,row in enumerate(data):
                 m,bins = numpy.histogram(row,normed=True,bins=50)
                 d = zip(bins[:-1],m)
